==> jvxall-1.2-sources.jar: com/sibvisions/rad/server/AbstractSessionContext.java <==
/*
 * Copyright 2013 SIB Visions GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 *
 * History
 *
 * 10.07.2013 - [JR] - creation
 */
package com.sibvisions.rad.server;

import java.util.Hashtable;

import javax.rad.remote.IConnectionConstants;
import javax.rad.server.IConfiguration;
import javax.rad.server.IServer;
import javax.rad.server.ISession;
import javax.rad.server.SessionContext;

/**
 * The <code>AbstractSessionContext</code> is a simple extension of {@link SessionContext}. It allows
 * indirect access to internal classes like MasterSession. 
 * 
 * @author Ren Jahn
 */
public abstract class AbstractSessionContext extends SessionContext
{
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	// Class members
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

	/** the associated session. */
	private WrappedSession wsessMaster;

	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    // User-defined methods
    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

	/**
	 * Gets the MasterSession for this context.
	 * 
	 * @return the session or <code>null</code> if no master session was found
	 */
	public ISession getMasterSession()
	{
		ISession session = getSession();
		
		if (wsessMaster != null)
		{
			return wsessMaster;
		}
		else
		{
			if (session instanceof WrappedSession)
			{
				AbstractSession sessorig = ((WrappedSession)session).session;
						
				if (sessorig instanceof MasterSession)
				{
					wsessMaster = (WrappedSession)session;
					
					return wsessMaster;
				}
				else if (sessorig instanceof SubSession)
				{
					wsessMaster = new WrappedSession(((SubSession)sessorig).getMasterSession());
					
					return wsessMaster;
				}
			}
		}
		
		return null;
	}
	
	//****************************************************************
	// Subclass definition
	//****************************************************************
	
	/**
	 * The <code>WrappedSession</code> allows restricted access to the 
	 * {@link AbstractSession}.
	 * 
	 * @author Ren Jahn
	 */
	protected static final class WrappedSession implements ISession
	{
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		// Class members
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

		/** the "hidden" session. */
		protected final AbstractSession session;
		
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		// Initialization
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		
		/**
		 * Creates a new instance of <code>WrappedSession</code> for an {@link ISession}.
		 * 
		 * @param pSession an {@link ISession} implementation
		 */
		protected WrappedSession(AbstractSession pSession)
		{
			session = pSession;
		}
		
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		// Interface implementation
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		
		/**
		 * {@inheritDoc}
		 */
		public Object getId()
		{
			return session.getId();
		}

		/**
		 * {@inheritDoc}
		 */
		public String getLifeCycleName()
		{
			return session.getLifeCycleName();
		}
		
		/**
		 * {@inheritDoc}
		 */
		public String getApplicationName()
		{
			return session.getApplicationName();
		}
		
		/**
		 * {@inheritDoc}
		 */
		public String getUserName()
		{
			return session.getUserName();
		}

		/**
		 * {@inheritDoc}
		 */
		public String getPassword()
		{
			return session.getPassword();
		}
		
		/**
		 * {@inheritDoc}
		 */
		public Object getProperty(String pName)
		{
			return session.getProperty(pName);
		}
		
		/**
		 * {@inheritDoc}
		 */
		public Hashtable<String, Object> getProperties()
		{
			return (Hashtable<String, Object>)session.getProperties().clone();
		}
		
		/**
		 * {@inheritDoc}
		 */
		public void setProperty(String pName, Object pValue)
		{
			if (pName != null && pName.startsWith(IConnectionConstants.PREFIX_CLIENT))
			{
				throw new SecurityException("It's not allowed to change client properties through the SessionContext!");
			}
			
			session.setProperty(pName, pValue);
		}

		/**
		 * {@inheritDoc}
		 */
		public long getStartTime()
		{
			return session.getStartTime();
		}

		/**
		 * {@inheritDoc}
		 */
		public long getLastAccessTime()
		{
			return session.getLastAccessTime();
		}

		/**
		 * {@inheritDoc}
		 */
		public long getLastAliveTime()
		{
			return session.getLastAliveTime();
		}

		/**
		 * {@inheritDoc}
		 */
		public void setAliveInterval(long pAliveInterval)
		{
			session.setAliveInterval(pAliveInterval);
		}

		/**
		 * {@inheritDoc}
		 */
		public long getAliveInterval()
		{
			return session.getAliveInterval();
		}

		/**
		 * {@inheritDoc}
		 */
		public boolean isAlive(long pAccessTime)
		{
			return session.isAlive(pAccessTime);
		}

		/**
		 * {@inheritDoc}
		 */
		public void setMaxInactiveInterval(int pMaxInactiveInterval)
		{
			session.setMaxInactiveInterval(pMaxInactiveInterval);
		}
		
		/**
		 * {@inheritDoc}
		 */
		public int getMaxInactiveInterval()
		{
			return session.getMaxInactiveInterval();
		}

		/**
		 * {@inheritDoc}
		 */
		public boolean isInactive(long pAccessTime)
		{
			return session.isInactive(pAccessTime);
		}

		/**
		 * {@inheritDoc}
		 */
		public Object call(String pObjectName, String pMethod, Object... pParams) throws Throwable
		{
			return session.call(pObjectName, pMethod, pParams);
		}
		
		/**
		 * {@inheritDoc}
		 */
		public Object callAction(String pAction, Object... pParams) throws Throwable
		{
			return session.callAction(pAction, pParams);
		}
		
		/**
		 * {@inheritDoc}
		 */
		public Object get(String pObjectName) throws Throwable
		{
			return session.get(pObjectName);
		}
		
		/**
		 * {@inheritDoc}
		 */
		public Object put(String pObjectName, Object pObject) throws Throwable
		{
			return session.put(pObjectName, pObject);
		}

		/**
		 * {@inheritDoc}
		 */
		public IConfiguration getConfig()
		{
			return session.getApplicationZone().getConfig();
		}
		
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		// User-defined methods
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

		/**
		 * Gets the server configuration.
		 * 
		 * @return the server configuration
		 */
		protected IConfiguration getServerConfig()
		{
			return session.getApplicationZone().getServerZone().getConfig();
		}
		
		/**
		 * Gets the referenced server.
		 * 
		 * @return the server
		 */
		protected IServer getServer()
		{
			return session.getSessionManager().getServer();
		}
		
	}	// WrappedSession
	
}	// AbstractSessionContext

==> jvxall-1.2.1-sources.jar: com/sibvisions/rad/server/AbstractSessionContext.java <==
/*
 * Copyright 2013 SIB Visions GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 *
 * History
 *
 * 10.07.2013 - [JR] - creation
 * 29.10.2013 - [JR] - #859: ignore missing ServerZone
 */
package com.sibvisions.rad.server;

import java.util.Hashtable;

import javax.rad.remote.IConnectionConstants;
import javax.rad.server.IConfiguration;
import javax.rad.server.IServer;
import javax.rad.server.ISession;
import javax.rad.server.SessionContext;

import com.sibvisions.rad.server.config.ServerZone;

/**
 * The <code>AbstractSessionContext</code> is a simple extension of {@link SessionContext}. It allows
 * indirect access to internal classes like MasterSession. 
 * 
 * @author Ren Jahn
 */
public abstract class AbstractSessionContext extends SessionContext
{
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	// Class members
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

	/** the associated session. */
	private WrappedSession wsessMaster;

	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    // User-defined methods
    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

	/**
	 * Gets the MasterSession for this context.
	 * 
	 * @return the session or <code>null</code> if no master session was found
	 */
	public ISession getMasterSession()
	{
		ISession session = getSession();
		
		if (wsessMaster != null)
		{
			return wsessMaster;
		}
		else
		{
			if (session instanceof WrappedSession)
			{
				AbstractSession sessorig = ((WrappedSession)session).session;
						
				if (sessorig instanceof MasterSession)
				{
					wsessMaster = (WrappedSession)session;
					
					return wsessMaster;
				}
				else if (sessorig instanceof SubSession)
				{
					wsessMaster = new WrappedSession(((SubSession)sessorig).getMasterSession());
					
					return wsessMaster;
				}
			}
		}
		
		return null;
	}
	
	//****************************************************************
	// Subclass definition
	//****************************************************************
	
	/**
	 * The <code>WrappedSession</code> allows restricted access to the 
	 * {@link AbstractSession}.
	 * 
	 * @author Ren Jahn
	 */
	protected static final class WrappedSession implements ISession
	{
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		// Class members
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

		/** the "hidden" session. */
		protected final AbstractSession session;
		
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		// Initialization
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		
		/**
		 * Creates a new instance of <code>WrappedSession</code> for an {@link ISession}.
		 * 
		 * @param pSession an {@link ISession} implementation
		 */
		protected WrappedSession(AbstractSession pSession)
		{
			session = pSession;
		}
		
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		// Interface implementation
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		
		/**
		 * {@inheritDoc}
		 */
		public Object getId()
		{
			return session.getId();
		}

		/**
		 * {@inheritDoc}
		 */
		public String getLifeCycleName()
		{
			return session.getLifeCycleName();
		}
		
		/**
		 * {@inheritDoc}
		 */
		public String getApplicationName()
		{
			return session.getApplicationName();
		}
		
		/**
		 * {@inheritDoc}
		 */
		public String getUserName()
		{
			return session.getUserName();
		}

		/**
		 * {@inheritDoc}
		 */
		public String getPassword()
		{
			return session.getPassword();
		}
		
		/**
		 * {@inheritDoc}
		 */
		public Object getProperty(String pName)
		{
			return session.getProperty(pName);
		}
		
		/**
		 * {@inheritDoc}
		 */
		public Hashtable<String, Object> getProperties()
		{
			return (Hashtable<String, Object>)session.getProperties().clone();
		}
		
		/**
		 * {@inheritDoc}
		 */
		public void setProperty(String pName, Object pValue)
		{
			if (pName != null && pName.startsWith(IConnectionConstants.PREFIX_CLIENT))
			{
				throw new SecurityException("It's not allowed to change client properties through the SessionContext!");
			}
			
			session.setProperty(pName, pValue);
		}

		/**
		 * {@inheritDoc}
		 */
		public long getStartTime()
		{
			return session.getStartTime();
		}

		/**
		 * {@inheritDoc}
		 */
		public long getLastAccessTime()
		{
			return session.getLastAccessTime();
		}

		/**
		 * {@inheritDoc}
		 */
		public long getLastAliveTime()
		{
			return session.getLastAliveTime();
		}

		/**
		 * {@inheritDoc}
		 */
		public void setAliveInterval(long pAliveInterval)
		{
			session.setAliveInterval(pAliveInterval);
		}

		/**
		 * {@inheritDoc}
		 */
		public long getAliveInterval()
		{
			return session.getAliveInterval();
		}

		/**
		 * {@inheritDoc}
		 */
		public boolean isAlive(long pAccessTime)
		{
			return session.isAlive(pAccessTime);
		}

		/**
		 * {@inheritDoc}
		 */
		public void setMaxInactiveInterval(int pMaxInactiveInterval)
		{
			session.setMaxInactiveInterval(pMaxInactiveInterval);
		}
		
		/**
		 * {@inheritDoc}
		 */
		public int getMaxInactiveInterval()
		{
			return session.getMaxInactiveInterval();
		}

		/**
		 * {@inheritDoc}
		 */
		public boolean isInactive(long pAccessTime)
		{
			return session.isInactive(pAccessTime);
		}

		/**
		 * {@inheritDoc}
		 */
		public Object call(String pObjectName, String pMethod, Object... pParams) throws Throwable
		{
			return session.call(pObjectName, pMethod, pParams);
		}
		
		/**
		 * {@inheritDoc}
		 */
		public Object callAction(String pAction, Object... pParams) throws Throwable
		{
			return session.callAction(pAction, pParams);
		}
		
		/**
		 * {@inheritDoc}
		 */
		public Object get(String pObjectName) throws Throwable
		{
			return session.get(pObjectName);
		}
		
		/**
		 * {@inheritDoc}
		 */
		public Object put(String pObjectName, Object pObject) throws Throwable
		{
			return session.put(pObjectName, pObject);
		}

		/**
		 * {@inheritDoc}
		 */
		public IConfiguration getConfig()
		{
			return session.getApplicationZone().getConfig();
		}
		
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		// User-defined methods
		//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

		/**
		 * Gets the server configuration.
		 * 
		 * @return the server configuration
		 */
		protected IConfiguration getServerConfig()
		{
			ServerZone zone = session.getApplicationZone().getServerZone();
			
			if (zone != null)
			{
				return zone.getConfig();
			}
			
			return null;
		}
		
		/**
		 * Gets the referenced server.
		 * 
		 * @return the server
		 */
		protected IServer getServer()
		{
			return session.getSessionManager().getServer();
		}
		
	}	// WrappedSession
	
}	// AbstractSessionContext
